=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2006-10-12 01:50:46 +0000
+++ bzrlib/repository.py	2006-11-06 21:00:45 +0000
@@ -2535,5 +2535,5 @@
     """Unescape predefined XML entities in a string of data."""
     global _unescape_re
     if _unescape_re is None:
-	_unescape_re = re.compile('\&([^;]*);')
+        _unescape_re = re.compile('\&([^;]*);')
     return _unescape_re.sub(_unescaper, data)

=== modified file 'bzrlib/shellcomplete.py'
--- bzrlib/shellcomplete.py	2006-10-05 05:37:25 +0000
+++ bzrlib/shellcomplete.py	2006-11-06 21:00:45 +0000
@@ -55,8 +55,8 @@
             if longname == on:
                 l = '"(--' + on + ' -' + shortname + ')"{--' + on + ',-' + shortname + '}'
                 break
-	    else:
-		l = '--' + on
+            else:
+                l = '--' + on
         outfile.write(l + '\n')
 
 
@@ -72,16 +72,16 @@
     cmds = []
     for cmdname, cmdclass in commands.get_all_cmds():
         cmds.append((cmdname, cmdclass))
-	for alias in cmdclass.aliases:
-	    cmds.append((alias, cmdclass))
+        for alias in cmdclass.aliases:
+            cmds.append((alias, cmdclass))
     cmds.sort()
     for cmdname, cmdclass in cmds:
         if cmdclass.hidden:
             continue
         doc = getdoc(cmdclass)
         if doc is None:
-	    outfile.write(cmdname + '\n')
+            outfile.write(cmdname + '\n')
         else:
-	    doclines = doc.splitlines()
-	    firstline = doclines[0].lower()
-	    outfile.write(cmdname + ':' + firstline[0:-1] + '\n')
+            doclines = doc.splitlines()
+            firstline = doclines[0].lower()
+            outfile.write(cmdname + ':' + firstline[0:-1] + '\n')

=== modified file 'bzrlib/tests/test_source.py'
--- bzrlib/tests/test_source.py	2006-10-31 04:32:20 +0000
+++ bzrlib/tests/test_source.py	2006-11-06 21:00:45 +0000
@@ -252,3 +252,17 @@
                 help_text.append((' '*4) + fname)
 
             self.fail('\n'.join(help_text))
+
+    def test_no_tabs(self):
+        """bzrlib source files should not contain any tab characters."""
+        incorrect = []
+
+        for fname, text in self.get_source_file_contents():
+            if '\t' in text:
+                incorrect.append(fname)
+
+        if incorrect:
+            self.fail('Tab characters were found in the following source files.'
+              '\nThey should either be replaced by "\\t" or by spaces:'
+              '\n\n    %s'
+              % ('\n    '.join(incorrect)))

